@@ -526,22 +526,13 @@ class ErrorCodes(object):
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
+        DiscountAmountCannotBeNegative = "915160"
+        DiscountAmountFormatIsInvalid = "915159"
+        DiscountAmountIsTooLarge = "915161"
         FailedAuthAdjustmentAllowRetry = "95603"
         FailedAuthAdjustmentHardDecline = "95602"
         FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
-        PaymentInstrumentWithExternalVaultIsInvalid = "915176"
-        DiscountAmountFormatIsInvalid = "915159"
-        DiscountAmountCannotBeNegative = "915160"
-        DiscountAmountIsTooLarge = "915161"
-        ShippingAmountFormatIsInvalid = "915162"
-        ShippingAmountCannotBeNegative = "915163"
-        ShippingAmountIsTooLarge = "915164"
-        ShippingPhoneNumberIsInvalid = "915204"
-        ShippingMethodIsInvalid = "915203"
-        ShipsFromPostalCodeIsTooLong = "915165"
-        ShipsFromPostalCodeIsInvalid = "915166"
-        ShipsFromPostalCodeInvalidCharacters = "915167"
         LineItemsExpected = "915158"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
         MerchantAccountDoesNotSupportMOTO = "91558"
@@ -555,6 +546,7 @@ class ErrorCodes(object):
         PayPalVaultRecordMissingData = "91583"
         PaymentInstrumentNotSupportedByMerchantAccount = "91577"
         PaymentInstrumentTypeIsNotAccepted = "915101"
+        PaymentInstrumentWithExternalVaultIsInvalid = "915176"
         PaymentMethodConflict = "91515"
         PaymentMethodConflictWithVenmoSDK = "91549"
         PaymentMethodDoesNotBelongToCustomer = "91516"
@@ -572,16 +564,17 @@ class ErrorCodes(object):
         ProcessorDoesNotSupportCredits = "91546"
         ProcessorDoesNotSupportMotoForCardType = "915195"
         ProcessorDoesNotSupportPartialSettlement = "915102"
-        ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingDescriptor = "915108"
+        ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingTransactionDetails = "915130"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
+        ProductSkuIsInvalid = "915202"
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
-        ProductSkuIsInvalid = "915202"
         RefundAmountIsTooLarge = "91521"
         RefundAuthHardDeclined = "915200"
         RefundAuthSoftDeclined = "915201"
+        ScaExemptionInvalid = "915213"
         ServiceFeeAmountCannotBeNegative = "91554"
         ServiceFeeAmountFormatIsInvalid = "91555"
         ServiceFeeAmountIsTooLarge = "91556"
@@ -591,6 +584,14 @@ class ErrorCodes(object):
         SettlementAmountIsLessThanServiceFeeAmount = "91551"
         SettlementAmountIsTooLarge = "91522"
         ShippingAddressDoesntMatchCustomer = "91581"
+        ShippingAmountCannotBeNegative = "915163"
+        ShippingAmountFormatIsInvalid = "915162"
+        ShippingAmountIsTooLarge = "915164"
+        ShippingMethodIsInvalid = "915203"
+        ShippingPhoneNumberIsInvalid = "915204"
+        ShipsFromPostalCodeInvalidCharacters = "915167"
+        ShipsFromPostalCodeIsInvalid = "915166"
+        ShipsFromPostalCodeIsTooLong = "915165"
         SubMerchantAccountRequiresServiceFeeAmount = "91553"
         SubscriptionDoesNotBelongToCustomer = "91529"
         SubscriptionIdIsInvalid = "91528"
@@ -610,11 +611,11 @@ class ErrorCodes(object):
         ThreeDSecureEciFlagIsRequired = "915113"
         ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         ThreeDSecureTokenIsInvalid = "91568"
-        ThreeDSecureTransactionPaymentMethodDoesntMatchThreeDSecureAuthenticationPaymentMethod = "915197"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
+        ThreeDSecureTransactionPaymentMethodDoesntMatchThreeDSecureAuthenticationPaymentMethod = "915197"
         ThreeDSecureXidIsRequired = "915115"
-        TransactionSourceIsInvalid = "915133"
         TooManyLineItems = "915157"
+        TransactionSourceIsInvalid = "915133"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
@@ -624,6 +625,7 @@ class ErrorCodes(object):
         class ExternalVault(object):
             StatusIsInvalid = "915175"
             StatusWithPreviousNetworkTransactionIdIsInvalid = "915177"
+            # NEXT_MAJOR_VERSION remove this validation error as it is no longer returned by the gateway
             CardTypeIsInvalid = "915178"
             PreviousNetworkTransactionIdIsInvalid = "915179"
 
@@ -758,6 +760,7 @@ class ErrorCodes(object):
         InvalidDepositAmounts = "96106"
 
     class RiskData(object):
+        # NEXT_MAJOR_VERSION Remove CustomerBrowserIsTooLong code as it is no longer used
         CustomerBrowserIsTooLong = "94701"
         CustomerDeviceIdIsTooLong = "94702"
         CustomerLocationZipInvalidCharacters = "94703"
